#!/usr/bin/python
# -*- coding: utf-8 -*-
import json
from django.utils.encoding import smart_unicode
from django.db.models import ProtectedError
from apella.management.utils import LoadDataCommand
from apella.models import ForeignInstitution


exempted = ['GREECE']

class Command(LoadDataCommand):

    def add_arguments(self, parser):
        parser.add_argument('json_file')

    def handle(self, *args, **options):

        # First delete all unused
        fis = ForeignInstitution.objects.all()
        existing_before = fis.count()
        deleted = 0
        for fi in fis:
            try:
                fi.delete()
                deleted += 1
            except ProtectedError:
                print("Skipping, ProtectedError: %s" % fi.university)
                continue

        file_path = options['json_file']
        with open(file_path) as json_file:
            data = json.load(json_file)
            data = data['data']
            added = 0
            existing = 0
            for item in data:
                country = item['country']
                country = country.encode("utf-8").strip()
                if country in exempted:
                    continue
                university = item['university']
                university = university.encode("utf-8").strip()
                try:
                    fi = ForeignInstitution.objects.get(
                        country=country, university=university
                    )
                    existing += 1
                    print("Skipping: %s" % university)
                    continue
                except ForeignInstitution.DoesNotExist:
                    ForeignInstitution.objects.create(
                        country=country, university=university
                    )
                    added += 1
                    #print("foreign institution created, country: %s"
                    #        ", university: %s" % (country, university))

            print("Before: %i, Deleted: %i" % (existing_before, deleted))
            print("Added: %i, Existing: %i" % (added, existing))
