from apella.models import MinistryCouncilAct
from apella.management.utils import LoadDataCommand, smart_locale_unicode


class Command(LoadDataCommand):

    MODEL = MinistryCouncilAct
    success = 0
    failed = 0

    def add_arguments(self, parser):
        parser.add_argument('--dry-run', dest='dry_run')
        super(Command, self).add_arguments(parser)

    def check_attr_is_int(self, title, attr, attr_name):
        try:
            int(attr)
        except ValueError:
            self.stdout.write(
                '----- Could not parse %s "%s" for title "%s"' % (attr_name, attr, title)  # noqa: E501
            )
            self.failed += 1

    def handle(self, *args, **options):
        file_path = options['csv_file']
        dry_run = options['dry_run']

        with open(file_path) as csv_file:
            for school_record in csv_file:
                title, month, year = self.preprocess(school_record)

                title = smart_locale_unicode(title)
                self.check_attr_is_int(title, month, "month")
                self.check_attr_is_int(title, year, "year")
                if not dry_run:
                    mca_obj = self.MODEL.objects.create(
                        title=title,
                        month=month,
                        year=year,
                    )
                    self.stdout.write(
                        "MinistryCouncilAct obj  created: %s %s %s %s" %
                        (mca_obj.id, title, month, year)
                    )
                else:
                    self.stdout.write(
                        "About to create MinistryCouncilAct obj: %s %s %s" %
                        (title, month, year)
                    )
                self.success += 1

            if self.success > 0:
                self.stdout.write(
                    "\nCreated: %d" % self.success)
            if self.failed > 0:
                self.stdout.write("Failed: %d" % self.failed)
